=== modified file 'breezy/builtins.py'
--- breezy/builtins.py	2019-07-27 22:47:49 +0000
+++ breezy/builtins.py	2019-09-01 15:33:59 +0000
@@ -2033,7 +2033,7 @@
         brz commit -m "imported project"
     """
 
-    _see_also = ['init-repository', 'branch', 'checkout']
+    _see_also = ['init-shared-repository', 'branch', 'checkout']
     takes_args = ['location?']
     takes_options = [
         Option('create-prefix',
@@ -2131,7 +2131,7 @@
                 self.outf.write(gettext("Using shared repository: %s\n") % url)
 
 
-class cmd_init_repository(Command):
+class cmd_init_shared_repository(Command):
     __doc__ = """Create a shared repository for branches to share storage space.
 
     New branches created under the repository directory will store their
@@ -2149,7 +2149,7 @@
     :Examples:
         Create a shared repository holding just branches::
 
-            brz init-repo --no-trees repo
+            brz init-shared-repo --no-trees repo
             brz init repo/trunk
 
         Make a lightweight checkout elsewhere::
@@ -2173,7 +2173,7 @@
                             help='Branches in the repository will default to'
                             ' not having a working tree.'),
                      ]
-    aliases = ["init-repo"]
+    aliases = ["init-shared-repo", "init-repo"]
 
     def run(self, location, format=None, no_trees=False):
         if format is None:

=== modified file 'breezy/help_topics/__init__.py'
--- breezy/help_topics/__init__.py	2019-06-16 19:53:27 +0000
+++ breezy/help_topics/__init__.py	2019-09-01 15:33:59 +0000
@@ -453,11 +453,11 @@
 generally a large space saving. For some operations (e.g. branching
 within the repository) this translates in to a large time saving.
 
-To create a shared repository use the init-repository command (or the alias
-init-repo). This command takes the location of the repository to create. This
-means that 'brz init-repository repo' will create a directory named 'repo',
-which contains a shared repository. Any new branches that are created in this
-directory will then use it for storage.
+To create a shared repository use the init-shared-repository command (or the
+alias init-shared-repo). This command takes the location of the repository to
+create. This means that 'brz init-shared-repository repo' will create a
+directory named 'repo', which contains a shared repository. Any new branches
+that are created in this directory will then use it for storage.
 
 It is a good idea to create a repository whenever you might create more
 than one branch of a project. This is true for both working areas where you
@@ -466,12 +466,12 @@
 trees. Since the files in the branch will not be edited directly there is no
 need to use up disk space for a working tree. To create a repository in which
 the branches will not have working trees pass the '--no-trees' option to
-'init-repository'.
+'init-shared-repository'.
 
 Related commands::
 
-  init-repository   Create a shared repository. Use --no-trees to create one
-                    in which new branches won't get a working tree.
+  init-shared-repository   Create a shared repository. Use --no-trees to create
+                           one in which new branches won't get a working tree.
 """
 
 

=== modified file 'breezy/plugins/bash_completion/tests/test_bashcomp.py'
--- breezy/plugins/bash_completion/tests/test_bashcomp.py	2018-11-11 04:08:32 +0000
+++ breezy/plugins/bash_completion/tests/test_bashcomp.py	2019-09-01 15:33:59 +0000
@@ -117,7 +117,8 @@
 
     def test_cmd_ini(self):
         self.complete(['brz', 'ini'])
-        self.assertCompletionContains('init', 'init-repo', 'init-repository')
+        self.assertCompletionContains(
+            'init', 'init-shared-repo', 'init-shared-repository')
         self.assertCompletionOmits('commit')
 
     def test_init_opts(self):
@@ -297,8 +298,9 @@
     def test_commands(self):
         dc = DataCollector()
         dc.commands()
-        self.assertSubset(['init', 'init-repo', 'init-repository'],
-                          dc.data.all_command_aliases())
+        self.assertSubset(
+            ['init', 'init-shared-repo', 'init-shared-repository'],
+            dc.data.all_command_aliases())
 
     def test_commands_from_plugins(self):
         dc = DataCollector()

=== modified file 'breezy/plugins/weave_fmt/test_repository.py'
--- breezy/plugins/weave_fmt/test_repository.py	2019-06-29 19:54:32 +0000
+++ breezy/plugins/weave_fmt/test_repository.py	2019-09-01 15:33:59 +0000
@@ -257,7 +257,7 @@
 class TestInterWeaveRepo(TestCaseWithTransport):
 
     def test_make_repository(self):
-        out, err = self.run_bzr("init-repository --format=weave a")
+        out, err = self.run_bzr("init-shared-repository --format=weave a")
         self.assertEqual(out,
                          """Standalone tree (format: weave)
 Location:

=== modified file 'breezy/tests/blackbox/test_branches.py'
--- breezy/tests/blackbox/test_branches.py	2018-07-07 15:06:42 +0000
+++ breezy/tests/blackbox/test_branches.py	2019-09-01 15:33:59 +0000
@@ -32,14 +32,14 @@
 
     def test_no_branch(self):
         # Listing the branches in a control directory without branches.
-        self.run_bzr('init-repo a')
+        self.run_bzr('init-shared-repo a')
         out, err = self.run_bzr('branches a')
         self.assertEqual(out, "")
 
     def test_default_current_dir(self):
         # "brz branches" list the branches in the current directory
         # if no location was specified.
-        self.run_bzr('init-repo a')
+        self.run_bzr('init-shared-repo a')
         out, err = self.run_bzr('branches', working_dir='a')
         self.assertEqual(out, "")
 

=== modified file 'breezy/tests/blackbox/test_push.py'
--- breezy/tests/blackbox/test_push.py	2019-02-16 04:57:50 +0000
+++ breezy/tests/blackbox/test_push.py	2019-09-01 15:33:59 +0000
@@ -949,7 +949,7 @@
 
     def test_push_with_revspec(self):
         self.run_script("""
-            $ brz init-repo .
+            $ brz init-shared-repo .
             Shared repository with trees (format: 2a)
             Location:
               shared repository: .

=== modified file 'breezy/tests/blackbox/test_reconfigure.py'
--- breezy/tests/blackbox/test_reconfigure.py	2018-11-11 04:08:32 +0000
+++ breezy/tests/blackbox/test_reconfigure.py	2019-09-01 15:33:59 +0000
@@ -190,7 +190,7 @@
 $ echo foo > branch/foo
 $ brz add -q branch/foo
 $ brz commit -q -m msg branch
-$ brz init-repo -q .
+$ brz init-shared-repo -q .
 $ brz reconfigure --branch --use-shared branch
 $ brz info branch
 Repository branch (format: ...)
@@ -205,7 +205,7 @@
 $ echo foo > branch/foo
 $ brz add -q branch/foo
 $ brz commit -q -m msg branch
-$ brz init-repo -q .
+$ brz init-shared-repo -q .
 $ brz reconfigure --use-shared --branch branch
 $ brz info branch
 Repository branch (format: ...)

=== modified file 'breezy/tests/blackbox/test_revision_history.py'
--- breezy/tests/blackbox/test_revision_history.py	2018-07-07 15:06:42 +0000
+++ breezy/tests/blackbox/test_revision_history.py	2019-09-01 15:33:59 +0000
@@ -55,14 +55,14 @@
     def test_revision_history_with_repo_branch(self):
         """With a repository branch location."""
         self._build_branch()
-        self.run_bzr('init-repo repo')
+        self.run_bzr('init-shared-repo repo')
         self.run_bzr('branch test repo/test')
         self._check_revision_history('repo/test')
 
     def test_revision_history_with_checkout(self):
         """With a repository branch checkout location."""
         self._build_branch()
-        self.run_bzr('init-repo repo')
+        self.run_bzr('init-shared-repo repo')
         self.run_bzr('branch test repo/test')
         self.run_bzr('checkout repo/test test-checkout')
         self._check_revision_history('test-checkout')
@@ -70,7 +70,7 @@
     def test_revision_history_with_lightweight_checkout(self):
         """With a repository branch lightweight checkout location."""
         self._build_branch()
-        self.run_bzr('init-repo repo')
+        self.run_bzr('init-shared-repo repo')
         self.run_bzr('branch test repo/test')
         self.run_bzr('checkout --lightweight repo/test test-checkout')
         self._check_revision_history('test-checkout')

=== modified file 'breezy/tests/blackbox/test_shared_repository.py'
--- breezy/tests/blackbox/test_shared_repository.py	2018-11-11 04:08:32 +0000
+++ breezy/tests/blackbox/test_shared_repository.py	2019-09-01 15:33:59 +0000
@@ -28,7 +28,7 @@
 class TestSharedRepo(TestCaseInTempDir):
 
     def test_make_repository(self):
-        out, err = self.run_bzr("init-repository a")
+        out, err = self.run_bzr("init-shared-repository a")
         self.assertEqual(out,
                          """Shared repository with trees (format: 2a)
 Location:
@@ -41,7 +41,7 @@
         self.assertRaises(errors.NoWorkingTree, dir.open_workingtree)
 
     def test_make_repository_quiet(self):
-        out, err = self.run_bzr("init-repository a -q")
+        out, err = self.run_bzr("init-shared-repository a -q")
         self.assertEqual(out, "")
         self.assertEqual(err, "")
         dir = ControlDir.open('a')
@@ -54,12 +54,12 @@
 
         (Malone #38331)
         """
-        out, err = self.run_bzr("init-repository .")
+        out, err = self.run_bzr("init-shared-repository .")
         dir = ControlDir.open('.')
         self.assertTrue(dir.open_repository())
 
     def test_init(self):
-        self.run_bzr("init-repo a")
+        self.run_bzr("init-shared-repo a")
         self.run_bzr("init --format=default a/b")
         dir = ControlDir.open('a')
         self.assertIs(dir.open_repository().is_shared(), True)
@@ -71,7 +71,7 @@
         wt = bdir.open_workingtree()
 
     def test_branch(self):
-        self.run_bzr("init-repo a")
+        self.run_bzr("init-shared-repo a")
         self.run_bzr("init --format=default a/b")
         self.run_bzr('branch a/b a/c')
         cdir = ControlDir.open('a/c')
@@ -80,7 +80,7 @@
         cdir.open_workingtree()
 
     def test_branch_tree(self):
-        self.run_bzr("init-repo --trees a")
+        self.run_bzr("init-shared-repo --trees a")
         self.run_bzr("init --format=default b")
         with open('b/hello', 'wt') as f:
             f.write('bar')
@@ -96,28 +96,28 @@
 
     def test_trees_default(self):
         # 0.15 switched to trees by default
-        self.run_bzr("init-repo repo")
+        self.run_bzr("init-shared-repo repo")
         repo = ControlDir.open("repo").open_repository()
         self.assertEqual(True, repo.make_working_trees())
 
     def test_trees_argument(self):
         # Supplying the --trees argument should be harmless,
         # as it was previously non-default we need to get it right.
-        self.run_bzr("init-repo --trees trees")
+        self.run_bzr("init-shared-repo --trees trees")
         repo = ControlDir.open("trees").open_repository()
         self.assertEqual(True, repo.make_working_trees())
 
     def test_no_trees_argument(self):
         # --no-trees should make it so that there is no working tree
-        self.run_bzr("init-repo --no-trees notrees")
+        self.run_bzr("init-shared-repo --no-trees notrees")
         repo = ControlDir.open("notrees").open_repository()
         self.assertEqual(False, repo.make_working_trees())
 
     def test_init_repo_smart_acceptance(self):
-        # The amount of hpss calls made on init-repo to a smart server should
-        # be fixed.
+        # The amount of hpss calls made on init-shared-repo to a smart server
+        # should be fixed.
         self.setup_smart_server_with_call_log()
-        self.run_bzr(['init-repo', self.get_url('repo')])
+        self.run_bzr(['init-shared-repo', self.get_url('repo')])
         # This figure represent the amount of work to perform this use case. It
         # is entirely ok to reduce this number if a test fails due to rpc_count
         # being too low. If rpc_count increases, more network roundtrips have
@@ -128,7 +128,7 @@
         self.assertThat(self.hpss_calls, ContainsNoVfsCalls)
 
     def test_notification_on_branch_from_repository(self):
-        out, err = self.run_bzr("init-repository -q a")
+        out, err = self.run_bzr("init-shared-repository -q a")
         self.assertEqual(out, "")
         self.assertEqual(err, "")
         dir = ControlDir.open('a')
@@ -150,19 +150,19 @@
         ControlDir.hooks.install_named_hook(
             'post_repo_init', calls.append, None)
         self.assertLength(0, calls)
-        self.run_bzr("init-repository a")
+        self.run_bzr("init-shared-repository a")
         self.assertLength(1, calls)
 
     def test_init_repo_without_username(self):
-        """Ensure init-repo works if username is not set.
+        """Ensure init-shared-repo works if username is not set.
         """
         # brz makes user specified whoami mandatory for operations
-        # like commit as whoami is recorded. init-repo however is not so final
-        # and uses whoami only in a lock file. Without whoami the login name
-        # is used. This test is to ensure that init-repo passes even when whoami
-        # is not available.
+        # like commit as whoami is recorded. init-shared-repo however is not so
+        # final and uses whoami only in a lock file. Without whoami the login name
+        # is used. This test is to ensure that init-shared-repo passes even
+        # when whoami is not available.
         self.overrideEnv('EMAIL', None)
         self.overrideEnv('BRZ_EMAIL', None)
-        out, err = self.run_bzr(['init-repo', 'foo'])
+        out, err = self.run_bzr(['init-shared-repo', 'foo'])
         self.assertEqual(err, '')
         self.assertTrue(os.path.exists('foo'))

=== modified file 'breezy/tests/blackbox/test_switch.py'
--- breezy/tests/blackbox/test_switch.py	2019-02-09 02:59:15 +0000
+++ breezy/tests/blackbox/test_switch.py	2019-09-01 15:33:59 +0000
@@ -407,7 +407,7 @@
         super(TestSwitchParentLocationBase, self).setUp()
         self.script_runner = script.ScriptRunner()
         self.script_runner.run_script(self, '''
-                $ brz init-repo --no-trees repo
+                $ brz init-shared-repo --no-trees repo
                 Shared repository...
                 Location:
                   shared repository: repo

=== modified file 'breezy/tests/blackbox/test_upgrade.py'
--- breezy/tests/blackbox/test_upgrade.py	2018-11-11 04:08:32 +0000
+++ breezy/tests/blackbox/test_upgrade.py	2019-09-01 15:33:59 +0000
@@ -189,7 +189,7 @@
                                    RepositoryFormatKnitPack1))
 
     def test_upgrade_repo(self):
-        self.run_bzr('init-repository --format=pack-0.92 repo')
+        self.run_bzr('init-shared-repository --format=pack-0.92 repo')
         self.run_bzr('upgrade --format=2a repo')
 
     def assertLegalOption(self, option_str):

=== modified file 'doc/developers/HACKING.txt'
--- doc/developers/HACKING.txt	2018-11-26 00:07:02 +0000
+++ doc/developers/HACKING.txt	2019-09-01 15:33:59 +0000
@@ -87,7 +87,7 @@
 copy of bzr.dev?`_.)
 ::
 
- $ brz init-repo ~/bzr
+ $ brz init-shared-repo ~/bzr
  $ cd ~/bzr
  $ brz branch lp:brz bzr.dev
 

=== modified file 'doc/developers/contribution-quickstart.txt'
--- doc/developers/contribution-quickstart.txt	2019-02-15 17:41:17 +0000
+++ doc/developers/contribution-quickstart.txt	2019-09-01 15:33:59 +0000
@@ -33,7 +33,7 @@
 First, get a local copy of Bazaar::
 
    $ cd $HOME
-   $ brz init-repo brz
+   $ brz init-shared-repo brz
    $ cd brz
    $ brz branch lp:brz brz.dev
 

=== modified file 'doc/developers/development-repo.txt'
--- doc/developers/development-repo.txt	2019-02-14 03:30:18 +0000
+++ doc/developers/development-repo.txt	2019-09-01 15:33:59 +0000
@@ -89,14 +89,14 @@
 for branches, you can make it a ``development`` repository like this::
 
   cd my-repo
-  bzr init-repo --development .
+  bzr init-shared-repo --development .
   cd my-stuff
   bzr init
   bzr add
   bzr commit -m "initial import"
 
 In other words, use the normal sequence of commands but add the
-``--development`` option to the ``init-repo`` command.
+``--development`` option to the ``init-shared-repo`` command.
 
 Upgrading an existing branch or repository to development
 ---------------------------------------------------------
@@ -141,7 +141,7 @@
 Here are the commands for the shared repository approach::
 
   cd my-repo
-  bzr init-repo --development .
+  bzr init-shared-repo --development .
   bzr branch my-source-branch my-new-branch
   cd my-new-branch
 

=== modified file 'doc/developers/packrepo.txt'
--- doc/developers/packrepo.txt	2018-11-18 13:43:04 +0000
+++ doc/developers/packrepo.txt	2019-09-01 15:33:59 +0000
@@ -58,14 +58,14 @@
 for branches, you can make it a ``knitpack`` repository like this::
 
   cd my-repo
-  bzr init-repo --pack-0.92 .
+  bzr init-shared-repo --pack-0.92 .
   cd my-stuff
   bzr init
   bzr add
   bzr commit -m "initial import"
 
 In other words, use the normal sequence of commands but add the
-``--pack-0.92`` option to the ``init-repo`` command.
+``--pack-0.92`` option to the ``init-shared-repo`` command.
 
 Upgrading an existing branch or repository to knitpack format
 -------------------------------------------------------------
@@ -110,7 +110,7 @@
 Here are the commands for the shared repository approach::
 
   cd my-repo
-  bzr init-repo --pack-0.92 .
+  bzr init-shared-repo --pack-0.92 .
   bzr branch my-source-branch my-new-branch
   cd my-new-branch
 

=== modified file 'doc/en/admin-guide/advanced.txt'
--- doc/en/admin-guide/advanced.txt	2009-12-22 05:22:53 +0000
+++ doc/en/admin-guide/advanced.txt	2019-09-01 15:33:59 +0000
@@ -61,7 +61,7 @@
 
   $ mkdir -p /srv/bzr
   $ cd /srv/bzr
-  $ bzr init-repo --no-trees projectx
+  $ bzr init-shared-repo --no-trees projectx
   $ cd projectx
   $ bzr branch bzr+ssh://server.example.com/srv/bzr/trunk
   $ bzr branch trunk australia-integration

=== modified file 'doc/en/admin-guide/simple-setups.txt'
--- doc/en/admin-guide/simple-setups.txt	2018-11-18 13:20:01 +0000
+++ doc/en/admin-guide/simple-setups.txt	2019-09-01 15:33:59 +0000
@@ -55,7 +55,7 @@
 shared repository to hold all of the branches.  To set this up, do::
 
   $ cd /srv/bzr
-  $ brz init-repo --no-trees projectx
+  $ brz init-shared-repo --no-trees projectx
 
 The ``--no-trees`` option saves space by not creating a copy of the working
 files on the server's filesystem.  Then, any branch created under

=== modified file 'doc/en/mini-tutorial/index.txt'
--- doc/en/mini-tutorial/index.txt	2017-06-19 19:47:45 +0000
+++ doc/en/mini-tutorial/index.txt	2019-09-01 15:33:59 +0000
@@ -65,7 +65,7 @@
 
 ::
 
-  $ brz init-repo sample
+  $ brz init-shared-repo sample
   Shared repository with trees (format: 2a)
   Location:
     shared repository: sample
@@ -193,7 +193,7 @@
 To work with someone else's code, you can make your own copy of their
 branch. Let's take a real-world example, Breezy's GTK interface::
 
-  $ brz init-repo ~/brz-gtk
+  $ brz init-shared-repo ~/brz-gtk
   $ brz branch lp:~brz/brz-gtk/trunk ~/brz-gtk/john
   Branched 292 revision(s).
 

=== modified file 'doc/en/release-notes/brz-3.1.txt'
--- doc/en/release-notes/brz-3.1.txt	2019-07-26 00:52:04 +0000
+++ doc/en/release-notes/brz-3.1.txt	2019-09-01 15:33:59 +0000
@@ -16,6 +16,11 @@
 
 .. These may require users to change the way they use Breezy.
 
+ * The ``brz init-repo`` command has been renamed to
+   ``brz init-shared-repo`` to emphasize that it creates
+   shared repositories rather than just any kind of repository.
+   (Jelmer Vernooĳ)
+
 New Features
 ************
 

=== modified file 'doc/en/tutorials/centralized_workflow.txt'
--- doc/en/tutorials/centralized_workflow.txt	2018-11-18 17:15:39 +0000
+++ doc/en/tutorials/centralized_workflow.txt	2019-09-01 15:33:59 +0000
@@ -60,7 +60,7 @@
 
 ::
 
-  % brz init-repo --trees ~
+  % brz init-shared-repo --trees ~
 
 
 Setting up a remote Repository
@@ -80,7 +80,7 @@
 
 ::
 
-  % brz init-repo --no-trees brz+ssh://centralhost/srv/brz/
+  % brz init-shared-repo --no-trees brz+ssh://centralhost/srv/brz/
 
 You can think of this step as similar to setting up a new cvsroot, or
 subversion repository.  The ``--no-trees`` option tells brz to not

=== modified file 'doc/en/user-guide/branching_a_project.txt'
--- doc/en/user-guide/branching_a_project.txt	2017-05-21 13:41:54 +0000
+++ doc/en/user-guide/branching_a_project.txt	2019-09-01 15:33:59 +0000
@@ -60,7 +60,7 @@
 `Organizing your workspace <organizing_your_workspace.html>`_
 for a commonly used layout.) For example::
 
-  brz init-repo my-repo
+  brz init-shared-repo my-repo
   cd my-repo
 
 You are now ready to grab a branch from someone else and

=== modified file 'doc/en/user-guide/organizing_branches.txt'
--- doc/en/user-guide/organizing_branches.txt	2017-05-21 13:41:54 +0000
+++ doc/en/user-guide/organizing_branches.txt	2019-09-01 15:33:59 +0000
@@ -14,7 +14,7 @@
 (or ``checkout``) command to create the mirror.
 For example::
 
-  brz init-repo PROJECT
+  brz init-shared-repo PROJECT
   cd PROJECT
   brz branch bzr+ssh://centralhost/srv/brz/PROJECT/trunk
 

=== modified file 'doc/en/user-guide/organizing_your_workspace.txt'
--- doc/en/user-guide/organizing_your_workspace.txt	2017-05-21 13:41:54 +0000
+++ doc/en/user-guide/organizing_your_workspace.txt	2019-09-01 15:33:59 +0000
@@ -105,7 +105,7 @@
 
 To set up::
 
-  brz init-repo project
+  brz init-shared-repo project
   cd project
   brz branch URL trunk
 
@@ -149,7 +149,7 @@
 
 To set up::
 
-  brz init-repo --no-trees project
+  brz init-shared-repo --no-trees project
   cd project
   brz branch URL trunk
   brz checkout --lightweight trunk sandbox

=== modified file 'doc/en/user-guide/publishing_a_branch.txt'
--- doc/en/user-guide/publishing_a_branch.txt	2017-05-21 13:35:49 +0000
+++ doc/en/user-guide/publishing_a_branch.txt	2019-09-01 15:33:59 +0000
@@ -16,7 +16,7 @@
 store history, not working copies of files, so their enclosing
 repository is usually creating using the ``no-trees`` option, e.g.::
 
-  brz init-repo --no-trees bzr+ssh://centralhost/srv/brz/PROJECT
+  brz init-shared-repo --no-trees bzr+ssh://centralhost/srv/brz/PROJECT
 
 You can think of this step as similar to setting up a new cvsroot or
 Subversion repository. However, Breezy gives you more flexibility
@@ -36,7 +36,7 @@
 
 Here is an example of the first way::
 
-  brz init-repo PROJECT  (prepare local repository)
+  brz init-shared-repo PROJECT  (prepare local repository)
   brz init PROJECT/trunk
   cd PROJECT/trunk
 			 (copy development files)
@@ -48,7 +48,7 @@
 
 Here is an example of the second way::
 
-  brz init-repo PROJECT  (prepare local repository)
+  brz init-shared-repo PROJECT  (prepare local repository)
   cd PROJECT
   brz init bzr+ssh://centralhost/srv/brz/PROJECT/trunk
   brz checkout bzr+ssh://centralhost/srv/brz/PROJECT/trunk

=== modified file 'doc/en/user-guide/reusing_a_checkout.txt'
--- doc/en/user-guide/reusing_a_checkout.txt	2017-05-21 13:41:54 +0000
+++ doc/en/user-guide/reusing_a_checkout.txt	2019-09-01 15:33:59 +0000
@@ -61,7 +61,7 @@
 with a local tree-less repository. This lets you switch what you
 are working on with ease. For example::
 
-  brz init-repo --no-trees PROJECT
+  brz init-shared-repo --no-trees PROJECT
   cd PROJECT
   brz branch bzr+ssh://centralhost/srv/brz/PROJECT/trunk
   brz checkout --lightweight trunk my-sandbox

=== modified file 'doc/en/user-guide/shared_repository_layouts.txt'
--- doc/en/user-guide/shared_repository_layouts.txt	2017-05-21 14:47:52 +0000
+++ doc/en/user-guide/shared_repository_layouts.txt	2019-09-01 15:33:59 +0000
@@ -54,7 +54,7 @@
 
 This also works with Breezy.
 However, with Breezy repositories are cheap to create
-(a simple ``brz init-repo`` away), and their primary benefit is when the
+(a simple ``brz init-shared-repo`` away), and their primary benefit is when the
 branches share a common ancestry.
 
 So the preferred way for Breezy would be::

=== modified file 'doc/en/user-guide/starting_a_project.txt'
--- doc/en/user-guide/starting_a_project.txt	2017-05-21 13:41:54 +0000
+++ doc/en/user-guide/starting_a_project.txt	2019-09-01 15:33:59 +0000
@@ -39,7 +39,7 @@
 idea to create a repository for the project at the top level and to nest
 a *main* branch within it like this::
 
-  brz init-repo my.repo
+  brz init-shared-repo my.repo
   cd my.repo
   brz init my.main
   cd my.main
@@ -50,6 +50,6 @@
 Some users prefer a name like *trunk* or *dev* to *main*. Choose
 whichever name makes the most sense to you.
 
-Note that the ``init-repo`` and ``init`` commands both take a path as an
+Note that the ``init-shared-repo`` and ``init`` commands both take a path as an
 argument and will create that path if it doesn't already exist.
 

=== modified file 'doc/en/user-guide/svn_plugin.txt'
--- doc/en/user-guide/svn_plugin.txt	2017-05-21 13:41:54 +0000
+++ doc/en/user-guide/svn_plugin.txt	2019-09-01 15:33:59 +0000
@@ -30,7 +30,7 @@
 GNOME project like **beagle**. Firstly, setup a local shared repository
 for storing your branches in and checkout the trunk::
 
-  brz init-repo beagle-repo
+  brz init-shared-repo beagle-repo
   cd beagle-repo
   brz checkout svn+ssh://svn.gnome.org/svn/beagle/trunk beagle-trunk
 
@@ -69,7 +69,7 @@
 
 Here's the recipe from above updated to use a central Breezy mirror::
 
-  brz init-repo beagle-repo
+  brz init-shared-repo beagle-repo
   cd beagle-repo
   brz branch bzr+ssh://brz.gnome.org/beagle.brz/trunk beagle-trunk
   brz branch beagle-trunk beagle-feature1

=== modified file 'tools/win32/build_release.py'
--- tools/win32/build_release.py	2018-11-16 13:02:50 +0000
+++ tools/win32/build_release.py	2019-09-01 15:33:59 +0000
@@ -136,7 +136,8 @@
     if not os.path.isdir(plugin_name):
         if plugin_name in ('bzr-svn', 'bzr-rewrite'):
             # bzr-svn uses a different repo format
-            call_or_fail([brz(), 'init-repo', '--rich-root-pack', plugin_name])
+            call_or_fail(
+                [brz(), 'init-shared-repo', '--rich-root-pack', plugin_name])
         else:
             os.mkdir(plugin_name)
     if os.path.isdir(release_dir):

